﻿namespace Expression.Blend.Design
{
    using System;
    using System.Windows;
    using System.ComponentModel;
    using System.Collections.ObjectModel;

    public class Note : INotifyPropertyChanged
    {
        #region --- INotifyPropertyChanged ---

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

        #region --- define properties ---

        private string _Title = string.Empty;

        public string Title
        {
            get
            {
                return this._Title;
            }

            set
            {
                if (this._Title != value)
                {
                    this._Title = value;
                    this.OnPropertyChanged("Title");
                }
            }
        }

        private string _CreationTime = string.Empty;

        public string CreationTime
        {
            get
            {
                return this._CreationTime;
            }

            set
            {
                if (this._CreationTime != value)
                {
                    this._CreationTime = value;
                    this.OnPropertyChanged("CreationTime");
                }
            }
        }

        private string _Content = string.Empty;

        public string Content
        {
            get
            {
                return this._Content;
            }

            set
            {
                if (this._Content != value)
                {
                    this._Content = value;
                    this.OnPropertyChanged("Content");
                }
            }
        }

        #endregion
    }

    public class NoteCollection : ObservableCollection<Note>
    { 
    
    }

    public class NoteBook : INotifyPropertyChanged
    {
        #region --- INotifyPropertyChanged ---

        public event PropertyChangedEventHandler PropertyChanged;

        protected virtual void OnPropertyChanged(string propertyName)
        {
            if (PropertyChanged != null)
            {
                PropertyChanged(this, new PropertyChangedEventArgs(propertyName));
            }
        }

        #endregion

        public NoteBook()
        {
            try
            {
                Uri resourceUri = new Uri("/LxhListBoxDemo;component/Design/SampleData.xaml", UriKind.Relative);
                if (Application.GetResourceStream(resourceUri) != null)
                {
                    Application.LoadComponent(this, resourceUri);
                }
            }
            catch (Exception)
            { 
                
            }
        }

        #region --- define properties ---

        private NoteCollection _NoteCollection = new NoteCollection();
        public NoteCollection NoteCollection
        {
            get { return _NoteCollection; }
            set 
            {
                if (_NoteCollection != value)
                {
                    _NoteCollection = value;
                    OnPropertyChanged("NoteCollection");
                }
            }
        }

        #endregion
    }
}